package com.ruoyi.buyerapi.mapper;


import com.ruoyi.buyerapi.domain.BuyerHelp;

import java.util.List;

/**
 * 帮助中心Mapper接口
 * 
 * @author ruoyi
 * @date 2022-10-12
 */
public interface BuyerHelpMapper 
{
    /**
     * 查询帮助中心
     * 
     * @param id 帮助中心主键
     * @return 帮助中心
     */
    public BuyerHelp selectBuyerHelpById(String id);

    /**
     * 查询帮助中心列表
     * 
     * @param buyerHelp 帮助中心
     * @return 帮助中心集合
     */
    public List<BuyerHelp> selectBuyerHelpList(BuyerHelp buyerHelp);

    /**
     * 新增帮助中心
     * 
     * @param buyerHelp 帮助中心
     * @return 结果
     */
    public int insertBuyerHelp(BuyerHelp buyerHelp);

    /**
     * 修改帮助中心
     * 
     * @param buyerHelp 帮助中心
     * @return 结果
     */
    public int updateBuyerHelp(BuyerHelp buyerHelp);

    /**
     * 删除帮助中心
     * 
     * @param id 帮助中心主键
     * @return 结果
     */
    public int deleteBuyerHelpById(String id);

    /**
     * 批量删除帮助中心
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteBuyerHelpByIds(String[] ids);
}
